@@ -3,11 +3,10 @@
 
 This file is part of PyVISA.
 
-:copyright: 2014-2020 by PyVISA Authors, see AUTHORS for more details.
+:copyright: 2014-2022 by PyVISA Authors, see AUTHORS for more details.
 :license: MIT, see LICENSE for more details.
 
 """
-import warnings
 from typing import Any, Tuple
 
 from . import typing, util
@@ -731,55 +730,12 @@ class LibraryError(OSError, Error):
             filename, "user" if filename == util.read_user_library_path() else "auto"
         )
         s += "No matching architecture.\n"
-        s += "    Current Python interpreter is %s bits\n" % details["bits"]
+        s += (
+            "    Current Python interpreter architecture: %s\n"
+            % details["architecture"]
+        )
         s += "    The library in: %s\n" % visalib.path
         s += "      found by: %s\n" % visalib.found_by
-        s += "      bitness: %s\n" % visalib.bitness
+        s += "      architecture: %s\n" % [str(a.value) for a in visalib.arch]
 
         return cls("Error while accessing %s: %s" % (filename, s))
-
-
-# TODO remove when removing return handler
-def _args_to_str(args: tuple, kwargs: dict) -> str:  # pragma: no cover
-    return "args=%s, kwargs=%s" % (args, kwargs)
-
-
-def return_handler(module_logger, first_is_session=True):  # pragma: no cover
-    """Decorate a VISA library function returning an error code."""
-    warnings.warn("return_handler will be removed in 1.12", FutureWarning)
-
-    def _outer(visa_library_method):
-        def _inner(self, session, *args, **kwargs):
-
-            ret_value = visa_library_method(*args, **kwargs)
-            module_logger.debug(
-                "%s%s -> %r",
-                visa_library_method.__name__,
-                _args_to_str(args, kwargs),
-                ret_value,
-            )
-
-            try:
-                ret_value = StatusCode(ret_value)
-            except ValueError:
-                pass
-
-            if first_is_session:
-                self._last_status = ret_value
-                self._last_status_in_session[session] = ret_value
-
-            if ret_value < 0:
-                raise VisaIOError(ret_value)
-
-            if ret_value in self.issue_warning_on:
-                if (
-                    session
-                    and ret_value not in self._ignore_warning_in_session[session]
-                ):
-                    module_logger.warn(VisaIOWarning(ret_value), stacklevel=2)
-
-            return ret_value
-
-        return _inner
-
-    return _outer
