@@ -6,6 +6,8 @@ import ctypes
 import gc
 import logging
 import time
+from types import ModuleType
+from typing import Optional
 
 import pytest
 
@@ -19,8 +21,11 @@ from .resource_utils import (
     ResourceTestCase,
 )
 
+np: Optional[ModuleType]
 try:
-    import numpy as np  # type: ignore
+    import numpy
+
+    np = numpy
 except ImportError:
     np = None
 
@@ -298,7 +303,8 @@ class MessagebasedResourceTestCase(ResourceTestCase):
             assert self.instr.read() == "\r1;2;3;4;5\r"
 
     @pytest.mark.parametrize(
-        "hfmt, prefix", zip(("ieee", "hp", "empty"), (b"#212", b"#A\x0c\x00", b""))
+        "hfmt, prefix",
+        list(zip(("ieee", "hp", "empty"), (b"#212", b"#A\x0c\x00", b""))),
     )
     def test_write_binary_values(self, hfmt, prefix):
         """Test writing binary data."""
@@ -350,11 +356,13 @@ class MessagebasedResourceTestCase(ResourceTestCase):
         with pytest.raises(ValueError):
             self.instr.write_binary_values("", values, "h", header_fmt="zxz")
 
-    def test_read_ascii_values(self):
+    # Without and with trailing comma
+    @pytest.mark.parametrize("msg", ["1,2,3,4,5", "1,2,3,4,5,"])
+    def test_read_ascii_values(self, msg):
         """Test reading ascii values."""
         # Standard separator
         self.instr.write("RECEIVE")
-        self.instr.write("1,2,3,4,5")
+        self.instr.write(msg)
         self.instr.write("SEND")
         values = self.instr.read_ascii_values()
         assert type(values[0]) is float
@@ -362,7 +370,7 @@ class MessagebasedResourceTestCase(ResourceTestCase):
 
         # Non standard separator and termination
         self.instr.write("RECEIVE")
-        self.instr.write("1;2;3;4;5")
+        self.instr.write(msg.replace(",", ";"))
         tic = time.time()
         values = self.instr.query_ascii_values(
             "SEND", converter="d", separator=";", delay=0.5
@@ -374,7 +382,7 @@ class MessagebasedResourceTestCase(ResourceTestCase):
         # Numpy container
         if np:
             self.instr.write("RECEIVE")
-            self.instr.write("1,2,3,4,5")
+            self.instr.write(msg)
             self.instr.write("SEND")
             values = self.instr.read_ascii_values(container=np.array)
             expected = np.array([1.0, 2.0, 3.0, 4.0, 5.0])
@@ -459,12 +467,10 @@ class MessagebasedResourceTestCase(ResourceTestCase):
     # Not sure how to test this
     @pytest.mark.skip
     def test_handling_malformed_binary(self):
-        """"""
+        """ """
         pass
 
-    @pytest.mark.parametrize(
-        "hfmt, header", zip(("ieee", "hp", "empty"), ("#10", "#A\x00\x00", ""))
-    )
+    @pytest.mark.parametrize("hfmt, header", list(zip(("ieee", "empty"), ("#0", ""))))
     def test_read_binary_values_unreported_length(self, hfmt, header):
         """Test reading binary data."""
         self.instr.read_termination = "\r"
@@ -526,6 +532,38 @@ class MessagebasedResourceTestCase(ResourceTestCase):
                 chunk_size=6,
             )
 
+    def test_read_binary_values_empty(self):
+        """Test reading binary data."""
+        self.instr.write("RECEIVE")
+        self.instr.write("#10")
+        self.instr.write("SEND")
+        new = self.instr.read_binary_values(
+            datatype="h",
+            is_big_endian=False,
+            header_fmt="ieee",
+            expect_termination=True,
+            chunk_size=6,
+        )
+        assert not new
+
+        if np:
+            self.instr.write("RECEIVE")
+            self.instr.write(
+                "#10",
+                termination="\n",
+            )
+            new = self.instr.query_binary_values(
+                "SEND",
+                datatype="h",
+                header_fmt="ieee",
+                is_big_endian=True,
+                expect_termination=False,
+                chunk_size=6,
+                container=np.array if np else list,
+            )
+
+            assert not new.size if np else not new
+
     def test_delay_in_query_ascii(self):
         """Test handling of the delay argument in query_ascii_values."""
         # Test using the instrument wide delay
@@ -560,7 +598,7 @@ class MessagebasedResourceTestCase(ResourceTestCase):
 
     def test_instrument_wide_delay_in_query_binary(self):
         """Test handling delay in query_ascii_values."""
-        header = "#10"
+        header = "#0"
         data = [1, 2, 3328, 3, 4, 5]
         # Test using the instrument wide delay
         self.instr.query_delay = 1.0
@@ -585,7 +623,7 @@ class MessagebasedResourceTestCase(ResourceTestCase):
 
     def test_delay_args_in_query_binary(self):
         """Test handling of the delay argument in query_ascii_values."""
-        header = "#10"
+        header = "#0"
         data = [1, 2, 3328, 3, 4, 5]
         self.instr.query_delay = 0.0
         self.instr.write("RECEIVE")
@@ -610,7 +648,7 @@ class MessagebasedResourceTestCase(ResourceTestCase):
 
     def test_no_delay_args_in_query_binary(self):
         """Test handling of the delay argument in query_ascii_values."""
-        header = "#10"
+        header = "#0"
         data = [1, 2, 3328, 3, 4, 5]
         self.instr.query_delay = 1.0
         self.instr.write("RECEIVE")
@@ -776,11 +814,6 @@ class EventAwareMessagebasedResourceTestCaseMixin(EventAwareResourceTestCaseMixi
         assert response.event.event_type == EventType.service_request
         assert self.instr.read() == "1"
 
-        with pytest.warns(FutureWarning):
-            response.event_type
-        with pytest.warns(FutureWarning):
-            response.context
-
     def test_managing_visa_handler(self):
         """Test using visa handlers."""
 
