@@ -10,9 +10,13 @@ import struct
 import subprocess
 import sys
 import tempfile
+import unittest
 from configparser import ConfigParser
 from functools import partial
 from io import StringIO
+from pathlib import Path
+from types import ModuleType
+from typing import Optional
 
 import pytest
 
@@ -20,8 +24,11 @@ from pyvisa import highlevel, util
 from pyvisa.ctwrapper import IVIVisaLibrary
 from pyvisa.testsuite import BaseTestCase
 
+np: Optional[ModuleType]
 try:
-    import numpy as np  # type: ignore
+    import numpy
+
+    np = numpy
 except ImportError:
     np = None
 
@@ -38,7 +45,9 @@ class TestConfigFile(BaseTestCase):
                 os.path.join(os.path.expanduser("~"), ".pyvisarc"),
             ]
         ):
-            self.skipTest(".pyvisarc file exists cannot properly test in this case")
+            raise unittest.SkipTest(
+                ".pyvisarc file exists cannot properly test in this case"
+            )
         self.temp_dir = tempfile.TemporaryDirectory()
         os.makedirs(os.path.join(self.temp_dir.name, "share", "pyvisa"))
         self.config_path = os.path.join(
@@ -158,7 +167,7 @@ class TestConfigFile(BaseTestCase):
 class TestParser(BaseTestCase):
     def test_parse_binary(self):
         s = (
-            b"#A@\xe2\x8b<@\xe2\x8b<@\xe2\x8b<@\xe2\x8b<@\xde\x8b<@\xde\x8b<@"
+            b"#0@\xe2\x8b<@\xe2\x8b<@\xe2\x8b<@\xe2\x8b<@\xde\x8b<@\xde\x8b<@"
             b"\xde\x8b<@\xde\x8b<@\xe0\x8b<@\xe0\x8b<@\xdc\x8b<@\xde\x8b<@"
             b"\xe2\x8b<@\xe0\x8b<"
         )
@@ -189,6 +198,10 @@ class TestParser(BaseTestCase):
         for a, b in zip(p, e):
             assert a == pytest.approx(b)
 
+        # Test handling zero length block
+        p = util.from_ieee_block(b"#10" + s[2:], datatype="f", is_big_endian=False)
+        assert not p
+
         p = util.from_hp_block(
             b"#A\x0e\x00" + s[2:],
             datatype="f",
@@ -203,7 +216,8 @@ class TestParser(BaseTestCase):
         for fmt in "d":
             msg = "block=%s, fmt=%s"
             msg = msg % ("ascii", fmt)
-            tb = lambda values: util.to_ascii_block(values, fmt, ",")
+            # Test handling the case of a trailing comma
+            tb = lambda values: util.to_ascii_block(values, fmt, ",") + ","
             fb = lambda block, cont: util.from_ascii_block(block, fmt, ",", cont)
             self.round_trip_block_conversion(values, tb, fb, msg)
 
@@ -281,10 +295,10 @@ class TestParser(BaseTestCase):
             (util.to_ieee_block, util.to_hp_block),
             (util.from_ieee_block, util.from_hp_block),
         ):
-            for fmt in "sp":
-                block = tb(values, datatype="s")
-                print(block)
-                rt = fb(block, datatype="s", container=bytes)
+            for fmt in "sbB":
+                block = tb(values, datatype=fmt)
+                print(fmt, block)
+                rt = fb(block, datatype=fmt, container=bytes)
                 assert values == rt
 
     def test_malformed_binary_block_header(self):
@@ -374,7 +388,7 @@ class TestParser(BaseTestCase):
                 block = block[:2] + b"0" * header_length + block[2 + header_length :]
             else:
                 block = block[:2] + b"\x00\x00\x00\x00" + block[2 + 4 :]
-            assert fb(block, "h", False, list) == values
+            assert not fb(block, "h", False, list)
 
     def test_handling_malformed_binary(self):
         containers = (list, tuple) + ((np.array, np.ndarray) if np else ())
@@ -496,27 +510,29 @@ class TestSystemDetailsAnalysis(BaseTestCase):
         util.system_details_to_str(details)
 
 
-def generate_fakelibs(dirname):
-
-    for name, blob in zip(
-        [
-            "fakelib_bad_magic.dll",
-            "fakelib_good_32.dll",
-            "fakelib_good_64_2.dll",
-            "fakelib_good_64.dll",
-            "fakelib_good_unknown.dll",
-            "fakelib_not_pe.dll",
-        ],
-        [
-            struct.pack("=6sH52sl", b"MAPE\x00\x00", 0x014C, 52 * b"\0", 2),
-            struct.pack("=6sH52sl", b"MZPE\x00\x00", 0x014C, 52 * b"\0", 2),
-            struct.pack("=6sH52sl", b"MZPE\x00\x00", 0x8664, 52 * b"\0", 2),
-            struct.pack("=6sH52sl", b"MZPE\x00\x00", 0x0200, 52 * b"\0", 2),
-            struct.pack("=6sH52sl", b"MZPE\x00\x00", 0xFFFF, 52 * b"\0", 2),
-            struct.pack("=6sH52sl", b"MZDE\x00\x00", 0x014C, 52 * b"\0", 2),
-        ],
-    ):
-        with open(os.path.join(dirname, name), "wb") as f:
+def generate_fakelibs(dirname: Path):
+    libs = {
+        "fakelib_bad_magic.dll": struct.pack(
+            "=6sH52sl", b"MAPE\x00\x00", 0x014C, 52 * b"\0", 2
+        ),
+        "fakelib_good_x86_32.dll": struct.pack(
+            "=6sH52sl", b"MZPE\x00\x00", 0x014C, 52 * b"\0", 2
+        ),
+        "fakelib_good_x86_64.dll": struct.pack(
+            "=6sH52sl", b"MZPE\x00\x00", 0x8664, 52 * b"\0", 2
+        ),
+        "fakelib_good_arm_64.dll": struct.pack(
+            "=6sH52sl", b"MZPE\x00\x00", 0xAA64, 52 * b"\0", 2
+        ),
+        "fakelib_good_unknown.dll": struct.pack(
+            "=6sH52sl", b"MZPE\x00\x00", 0xFFFF, 52 * b"\0", 2
+        ),
+        "fakelib_not_pe.dll": struct.pack(
+            "=6sH52sl", b"MZDE\x00\x00", 0x014C, 52 * b"\0", 2
+        ),
+    }
+    for name, blob in libs.items():
+        with open(dirname / name, "wb") as f:
             f.write(blob)
             print("Written %s" % name)
 
@@ -524,53 +540,52 @@ def generate_fakelibs(dirname):
 class TestLibraryAnalysis(BaseTestCase):
     """Test (through monkey patching) the analysis of binary libraries."""
 
-    def test_get_shared_library_arch(self, tmpdir):
+    def test_get_shared_library_arch(self, tmp_path: Path):
         """Test analysing a library on Windows."""
-        dirname = str(tmpdir)
-        generate_fakelibs(dirname)
+        generate_fakelibs(tmp_path)
 
-        for f, a in zip(["_32", "_64", "_64_2"], ["I386", "IA64", "AMD64"]):
-            arch = util.get_shared_library_arch(
-                os.path.join(tmpdir, "fakelib_good%s.dll" % f)
-            )
+        for f, a in zip(
+            ["x86_32", "x86_64", "arm_64"],
+            [
+                util.PEMachineType.I386,
+                util.PEMachineType.AMD64,
+                util.PEMachineType.AARCH64,
+            ],
+        ):
+            arch = util.get_shared_library_arch(tmp_path / f"fakelib_good_{f}.dll")
             assert arch == a
 
-        arch = util.get_shared_library_arch(
-            os.path.join(dirname, "fakelib_good_unknown.dll")
-        )
-        assert arch == "UNKNOWN"
+        arch = util.get_shared_library_arch(tmp_path / "fakelib_good_unknown.dll")
+        assert arch == util.PEMachineType.UNKNOWN
 
         with pytest.raises(Exception) as e:
-            util.get_shared_library_arch(os.path.join(dirname, "fakelib_bad_magic.dll"))
+            util.get_shared_library_arch(tmp_path / "fakelib_bad_magic.dll")
         assert "Not an executable" in e.exconly()
 
         with pytest.raises(Exception) as e:
-            util.get_shared_library_arch(os.path.join(dirname, "fakelib_not_pe.dll"))
+            util.get_shared_library_arch(tmp_path / "fakelib_not_pe.dll")
         assert "Not a PE executable" in e.exconly()
 
-    def test_get_arch_windows(self, tmpdir):
+    def test_get_arch_windows(self, tmp_path: Path):
         """Test identifying the computer architecture on windows."""
-        dirname = str(tmpdir)
-        generate_fakelibs(dirname)
+        generate_fakelibs(tmp_path)
 
         platform = sys.platform
         sys.platform = "win32"
         try:
             for f, a in zip(
-                ["_32", "_64", "_64_2", "_unknown"], [(32,), (64,), (64,), ()]
+                ["x86_32", "x86_64", "arm_64", "_unknown"],
+                [
+                    [util.ArchitectureType.I386],
+                    [util.ArchitectureType.X86_64],
+                    [util.ArchitectureType.AARCH64],
+                    [],
+                ],
             ):
                 print(f, a)
-                path = os.path.join(dirname, "fakelib_good%s.dll" % f)
-                lib = util.LibraryPath(path)
+                path = tmp_path / f"fakelib_good_{f}.dll"
+                lib = util.LibraryPath(str(path))
                 assert lib.arch == a
-                if f != "_unknown":
-                    assert lib.is_32bit if 32 in a else not lib.is_32bit
-                    assert lib.is_64bit if 64 in a else not lib.is_64bit
-                    assert lib.bitness == ", ".join(str(b) for b in a)
-                else:
-                    assert lib.is_32bit == "n/a"
-                    assert lib.is_64bit == "n/a"
-                    assert lib.bitness == "n/a"
         finally:
             sys.platform = platform
 
@@ -589,19 +604,16 @@ class TestLibraryAnalysis(BaseTestCase):
             subprocess.run = alt_run
 
             for p, f, a in [
-                ("linux2", "32-bit", (32,)),
-                ("linux2", "32-bit & 64-bit", (32, 64)),
-                ("linux3", "64-bit", (64,)),
-                ("darwin", "(for architecture i386)", (32,)),
-                ("darwin", "(for architecture x86_64)", (64,)),
+                ("linux", "80386", [(util.ArchitectureType.I386)]),
+                ("linux", "x86-64", [(util.ArchitectureType.X86_64)]),
+                ("linux", "aarch64", [(util.ArchitectureType.AARCH64)]),
+                ("darwin", "executable i386", [(util.ArchitectureType.I386)]),
+                ("darwin", "executable x86_64", [(util.ArchitectureType.X86_64)]),
+                ("darwin", "executable arm64", [(util.ArchitectureType.AARCH64)]),
             ]:
                 sys.platform = p
                 lib = util.LibraryPath(f)
                 assert lib.arch == a
-                assert lib.is_32bit if 32 in a else not lib.is_32bit
-                assert lib.is_64bit if 64 in a else not lib.is_64bit
-                assert lib.bitness == ", ".join(str(b) for b in a)
-
         finally:
             sys.platform = platform
             subprocess.run = run
@@ -613,10 +625,7 @@ class TestLibraryAnalysis(BaseTestCase):
         try:
             sys.platform = "darwin"
             lib = util.LibraryPath("")
-            assert lib.arch == ()
-            assert lib.is_32bit == "n/a"
-            assert lib.is_64bit == "n/a"
-            assert lib.bitness == "n/a"
+            assert lib.arch == []
         finally:
             sys.platform = platform
             subprocess.run = run
@@ -628,10 +637,7 @@ class TestLibraryAnalysis(BaseTestCase):
         try:
             sys.platform = "test"
             lib = util.LibraryPath("")
-            assert lib.arch == ()
-            assert lib.is_32bit == "n/a"
-            assert lib.is_64bit == "n/a"
-            assert lib.bitness == "n/a"
+            assert lib.arch == []
         finally:
             sys.platform = platform
             subprocess.run = run
